<?php
/*
 *  Demo MyPlaza Module (does nothing particularly useful :P)
 * NOTE: the filename of modules may only contain letters, numbers and the underscore character
 */

if(!defined("IN_MYBB"))
	die("This file cannot be accessed directly.");

/**********************************************
 * Note with functions - all functions here
 * may be called by MyPlaza
 **********************************************/

/* language definitions - I stick this near the top to make it easier to edit
 *  I suggest having this here, instead of using a separate .lang file because
 *  it allows most modules to be put into one file (and ideal for MyPlaza's module
 *  uploading from within the AdminCP)
 *  The disadvantage with using this method is that language variables can no
 *  longer be edited from the AdminCP.
 *  I may provide a feature to write variables in this function to a .lang file,
 *  if the languages folder is writable, in a later version of MyPlaza
 * This function will automatically be called in various locations, for your
 *  convenience.  The $lang object, with these languages definitions will
 *  automatically be available in the following functions:
 *  - demo_page()
 *  - demo_run()
 *  - and in the plaza (for htmlextra eval'ing)
 */
function demo_lang()
{
	global $mybb, $l;
	switch($mybb->settings['bblanguage'])
	{
		// stick your extra languages here, eg:
		// case 'randomlanguage':
		// 	$l['hello'] = 'aslfkdjoiqwerpo';
		//   ...
		// 	break;
		
		// default to english
		//case 'english':
		default:
			$l['thread_id'] = 'Thread ID';
			$l['thread_change_views_to'] = 'Change views to';
			
			$l['reset_post_count'] = 'Successfully reset postcount';
			$l['set_postcount_0'] = 'Set postcount to 0';
			
			$l['invalid_thread'] = 'Invalid thread specified.';
			$l['thread_viewcount_change'] = 'Thread\'s viewcount changed to {1}.';
			$l['thread_viewcount_change_log'] = 'Set viewcount of thread <a href="showthread.php?tid={1}" target="_blank">{2}</a> to {3}';
	}
}

/* Like above, but for AdminCP language stuff
 *  These values are automatically available in the $lang object in the following functions:
 *  - demo_activate()
 *  - demo_admin()
 *  - demo_info()
 */
function demo_lang_admin()
{
	global $mybb, $l;
	switch($mybb->settings['bblanguage'])
	{
		// add extra languages here
		default:
			$l['demo_name'] = 'Demo Module';
			$l['demo_description'] = 'Demo module - shows the basic structure of how to make a module for MyPlaza';
			
			$l['demo_item1'] = 'Set post count to 0';
			$l['demo_descript1'] = 'A useless demo item which will reset your post count';
			$l['demo_item2'] = 'Set thread views';
			$l['demo_descript2'] = 'Another useless demo item which allows you to set the viewcount of a thread.';
			
			$l['allow_negative_thread_views'] = 'Allow negative thread views';
			$l['allow_negative_thread_views_desc'] = 'Allow users to set a negative thread view count.';
			
			$l['demo_options'] = 'Demo Options';
	}
}


// basically the same as a normal plugin
function demo_info()
{
	global $lang;
	return array(
		"name"			=> $lang->demo_name,
		"description"	=> $lang->demo_description,
		"website"		=> "http://yourwebsite.com/",
		"author"		=> "Your name here",
		"authorsite"	=> "http://authorwebsite.com/",
		"version"		=> "1.0",
		
		// strictly optional, but I recommend putting in a list of which versions
		//  of MyPlaza this module works under
		"compatibility"	=> array(0.1)
	);
}

/* if you put this function in, the module will be run as a MyBB plugin
 * with this function being executed (I recommend using a function rather than adding
 *  plugin hooks globally, as this file is included at various other places)
 *
 *  You should put your plugin hooks here
 * Please note: if you don't want this module to be run as a plugin, do NOT include this function
 * 
 * We will not be running this module as a plugin, however, it's included here for
 *  demonstration purposes.
 */
function demo_plugin()
{
	// add hooks here
	//global $plugins;
	//$plugins->add_hook('somehook', 'myfunction');
}


// same methods as plugins
function demo_activate()
{
	global $db, $lang;
	
	// we'll insert a setting
	$db->insert_query(TABLE_PREFIX."settings", array(
		"name" => 'demo_allow_negative_views',
		"title" => $lang->allow_negative_thread_views,
		"description" => $lang->allow_negative_thread_views_desc,
		"optionscode" => 'yesno',
		"value" => 'yes',
		"disporder" => 1,
		// we insert it to gid #0, so that MyBB's settings area doesn't get
		//  cluttered (this setting won't be visible from MyBB's settings editor)
		"gid" => 0,
	));
	
	rebuildsettings();
	
	// add items
	//  note: htmlextra is eval'd, which allows the use of the {$lang->} notation
	$item1 = array(
		// name of the item
		"name" => $lang->demo_item1,
		// a unique id for the item
		"idname" => 'demo1',
		"description" => $lang->demo_descript1,
		
		// the following values just specify defaults upon installation
		"visible" => 'yes',
		"cost" => 0,
		"infstock" => 'yes', // infinite stock
		"buylimitamount" => 0,	// not used for infinite stock
		"buylimittime" => 0,	// not used for infinite stock
		"restockamount" => 0,	// not used for infinite stock
		"restocktime" => 0,		// not used for infinite stock
		// any extra HTML to show when purchasing an item (ie extra textboxes etc)
		"htmlextra" => '<input type="hidden" name="demovalue" value="1" />',
	);
	myplaza_add_item($item1, 'demo');
	$item2 = array(
		"name" => $lang->demo_item2,
		"idname" => 'demo2',
		"description" => $lang->demo_descript2,
		"visible" => 'yes',
		"cost" => 10.5, // note about decimals - these may be rounded off if the user has limited the number places
		"infstock" => 'no',
		"buylimitamount" => 2,
		"buylimittime" => 3600, // a user cannot buy more than 2 of this item within an hour
		"restockamount" => 5,
		"restocktime" => 1800,  // the stock is restored by 5 every half hour
		"stock" => 5,  // note this is an additional field - specified the amount of stock available upon installation
		"htmlextra" => '<table border="0" cellpadding="0" cellspacing="0" style="color: white;"><tr><td>{$lang->thread_id}:</td><td><input type="text" name="tid" value="" class="textbox" /></td></tr>
						<tr><td>{$lang->thread_change_views_to}:</td><td><input type="text" name="views" value="" class="textbox" /></td></tr></table>',
	);
	myplaza_add_item($item2, 'demo');
	
}

function demo_deactivate()
{
	global $db;
	$db->delete_query(TABLE_PREFIX.'settings', 'name = \'demo_allow_negative_views\'');
	rebuildsettings();
	
	// remove all items from demo
	myplaza_remove_module_items('demo');
}


// this procedure is run when any item which links to the current script is bought
// returns true if buy is successful, false otherwise
function demo_run($item)
{
	// if you want to send the user custom messages, and/or want custom text to be displaed in the log,
	// you'll need to change these variables
	global $buyRtnMsg, $buyLogMsg;
	
	global $lang;
	
	// which item did they buy?
	switch($item['idname'])
	{
		case 'demo1':
			// this demo item will set the current's users # of posts to 0
			global $mybb, $db;
			$db->update_query(TABLE_PREFIX."users", array('postnum' => 0), "uid='".$mybb->user['uid']."'");
			
			$buyRtnMsg = $lang->reset_post_count;
			$buyLogMsg = $lang->set_postcount_0;
			return true;
			
		case 'demo2':
			// this random item allows buyer to set the number of views a thread has
			global $mybb, $db;
			$tid = intval($mybb->input['tid']);
			$views = intval($mybb->input['views']);
			if(!($thread = get_thread($tid)))
			{
				$buyRtnMsg = $lang->invalid_thread;
				return false;
			}
			
			// check for negative view count
			if($mybb->settings['demo_allow_negative_views'] == 'no' && $views < 0)
			{
				// we'll leave the user wondering what happened :P
				//  by not giving a message
				return false;
			}
			
			// set number of views
			$db->update_query(TABLE_PREFIX."threads", array('views' => $views), "tid='".$tid."'");
			
			$buyRtnMsg = sprintf($lang->thread_viewcount_change, $views);
			$buyLogMsg = sprintf($lang->thread_viewcount_change_log, $tid, $thread['subject'],$views);
			return true;
			
		default:
			$buyRtnMsg = 'Invalid item.';
			return false;
	}
}

// function is run for things in the AdminCP
// @process: bool  true if processing options, false if displaying options
function demo_admin($process)
{
	// process this part when setting options
	if($process)
	{
		myplaza_process_settings(array('demo_allow_negative_views'));
	}
	// process this part for displaying options
	else
	{
		global $lang;
		
		// next line is required (usually)
		cpheader_myplaza_module();
		starttable();
		tableheader($lang->demo_options, "", 2);
		myplaza_generate_settings_code(array('demo_allow_negative_views'));
		endtable();
		
		cpfooter_myplaza_module();
	}
}


// include this function if you want a custom page for the module
// this page is accessible by /plaza.php?action=page&p=demo
// this is somewhat similar to hooking the plaza.php page and checking for actions,
//  but I've provided this function here for convenience purposes :P
function demo_page()
{
	error('Nothing to do... :|');
}


?>